# digitalai.release.v1
No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: v1
- Package version: 1.0.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

## Requirements.

Python >=3.6

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import digitalai.release.v1
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import digitalai.release.v1
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import time
import digitalai.release.v1
from pprint import pprint
from digitalai.release.v1.api import activity_logs_api
from digitalai.release.v1.model.activity_log_entry import ActivityLogEntry
# Defining the host is optional and defaults to http://localhost:5516
# See configuration.py for a list of all supported configuration parameters.
configuration = digitalai.release.v1.Configuration(
    host = "http://localhost:5516"
)

# The client must configure the authentication and authorization parameters
# in accordance with the API server security policy.
# Examples for each auth method are provided below, use the example that
# satisfies your auth use case.

# Configure HTTP basic authorization: basicAuth
configuration = digitalai.release.v1.Configuration(
    username = 'YOUR_USERNAME',
    password = 'YOUR_PASSWORD'
)

# Configure API key authorization: patAuth
configuration.api_key['patAuth'] = 'YOUR_API_KEY'

# Uncomment below to setup prefix (e.g. Bearer) for API key, if needed
# configuration.api_key_prefix['patAuth'] = 'Bearer'


# Enter a context with an instance of the API client
with digitalai.release.v1.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = activity_logs_api.ActivityLogsApi(api_client)
    container_id = "jUR,rZ#UM/?R,Fp^l6$ARj/Release*" # str | 

    try:
        api_response = api_instance.get_activity_logs(container_id)
        pprint(api_response)
    except digitalai.release.v1.ApiException as e:
        print("Exception when calling ActivityLogsApi->get_activity_logs: %s\n" % e)
```

## Documentation for API Endpoints

All URIs are relative to *http://localhost:5516*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*ActivityLogsApi* | [**get_activity_logs**](docs/ActivityLogsApi.md#get_activity_logs) | **GET** /api/v1/activities/{containerId} | 
*ApplicationApi* | [**create_application**](docs/ApplicationApi.md#create_application) | **POST** /api/v1/applications | 
*ApplicationApi* | [**delete_application**](docs/ApplicationApi.md#delete_application) | **DELETE** /api/v1/applications/{applicationId} | 
*ApplicationApi* | [**get_application**](docs/ApplicationApi.md#get_application) | **GET** /api/v1/applications/{applicationId} | 
*ApplicationApi* | [**search_applications**](docs/ApplicationApi.md#search_applications) | **POST** /api/v1/applications/search | 
*ApplicationApi* | [**update_application**](docs/ApplicationApi.md#update_application) | **PUT** /api/v1/applications/{applicationId} | 
*ConfigurationApi* | [**add_configuration**](docs/ConfigurationApi.md#add_configuration) | **POST** /api/v1/config | 
*ConfigurationApi* | [**add_global_variable**](docs/ConfigurationApi.md#add_global_variable) | **POST** /api/v1/config/Configuration/variables/global | 
*ConfigurationApi* | [**check_status**](docs/ConfigurationApi.md#check_status) | **POST** /api/v1/config/status | 
*ConfigurationApi* | [**check_status1**](docs/ConfigurationApi.md#check_status1) | **POST** /api/v1/config/{configurationId}/status | 
*ConfigurationApi* | [**delete_configuration**](docs/ConfigurationApi.md#delete_configuration) | **DELETE** /api/v1/config/{configurationId} | 
*ConfigurationApi* | [**delete_global_variable**](docs/ConfigurationApi.md#delete_global_variable) | **DELETE** /api/v1/config/{variableId} | 
*ConfigurationApi* | [**get_configuration**](docs/ConfigurationApi.md#get_configuration) | **GET** /api/v1/config/{configurationId} | 
*ConfigurationApi* | [**get_global_variable**](docs/ConfigurationApi.md#get_global_variable) | **GET** /api/v1/config/{variableId} | 
*ConfigurationApi* | [**get_global_variable_values**](docs/ConfigurationApi.md#get_global_variable_values) | **GET** /api/v1/config/Configuration/variableValues/global | 
*ConfigurationApi* | [**get_global_variables**](docs/ConfigurationApi.md#get_global_variables) | **GET** /api/v1/config/Configuration/variables/global | 
*ConfigurationApi* | [**get_system_message**](docs/ConfigurationApi.md#get_system_message) | **GET** /api/v1/config/system-message | 
*ConfigurationApi* | [**search_by_type_and_title**](docs/ConfigurationApi.md#search_by_type_and_title) | **GET** /api/v1/config/byTypeAndTitle | 
*ConfigurationApi* | [**update_configuration**](docs/ConfigurationApi.md#update_configuration) | **PUT** /api/v1/config/{configurationId} | 
*ConfigurationApi* | [**update_global_variable**](docs/ConfigurationApi.md#update_global_variable) | **PUT** /api/v1/config/{variableId} | 
*ConfigurationApi* | [**update_system_message**](docs/ConfigurationApi.md#update_system_message) | **PUT** /api/v1/config/system-message | 
*DeliveryApi* | [**complete_stage**](docs/DeliveryApi.md#complete_stage) | **POST** /api/v1/deliveries/{stageId}/complete | 
*DeliveryApi* | [**complete_tracked_item**](docs/DeliveryApi.md#complete_tracked_item) | **PUT** /api/v1/deliveries/{stageId}/{itemId}/complete | 
*DeliveryApi* | [**complete_transition**](docs/DeliveryApi.md#complete_transition) | **POST** /api/v1/deliveries/{transitionId}/complete | 
*DeliveryApi* | [**create_tracked_item_in_delivery**](docs/DeliveryApi.md#create_tracked_item_in_delivery) | **POST** /api/v1/deliveries/{deliveryId}/tracked-items | 
*DeliveryApi* | [**delete_delivery**](docs/DeliveryApi.md#delete_delivery) | **DELETE** /api/v1/deliveries/{deliveryId} | 
*DeliveryApi* | [**delete_tracked_item_delivery**](docs/DeliveryApi.md#delete_tracked_item_delivery) | **DELETE** /api/v1/deliveries/{itemId} | 
*DeliveryApi* | [**descope_tracked_item**](docs/DeliveryApi.md#descope_tracked_item) | **PUT** /api/v1/deliveries/{itemId}/descope | 
*DeliveryApi* | [**get_delivery**](docs/DeliveryApi.md#get_delivery) | **GET** /api/v1/deliveries/{deliveryId} | 
*DeliveryApi* | [**get_delivery_timeline**](docs/DeliveryApi.md#get_delivery_timeline) | **GET** /api/v1/deliveries/{deliveryId}/timeline | 
*DeliveryApi* | [**get_releases_for_delivery**](docs/DeliveryApi.md#get_releases_for_delivery) | **GET** /api/v1/deliveries/{deliveryId}/releases | 
*DeliveryApi* | [**get_stages_in_delivery**](docs/DeliveryApi.md#get_stages_in_delivery) | **GET** /api/v1/deliveries/{deliveryId}/stages | 
*DeliveryApi* | [**get_tracked_itemsin_delivery**](docs/DeliveryApi.md#get_tracked_itemsin_delivery) | **GET** /api/v1/deliveries/{deliveryId}/tracked-items | 
*DeliveryApi* | [**reopen_stage**](docs/DeliveryApi.md#reopen_stage) | **POST** /api/v1/deliveries/{stageId}/reopen | 
*DeliveryApi* | [**rescope_tracked_item**](docs/DeliveryApi.md#rescope_tracked_item) | **PUT** /api/v1/deliveries/{itemId}/rescope | 
*DeliveryApi* | [**reset_tracked_item**](docs/DeliveryApi.md#reset_tracked_item) | **PUT** /api/v1/deliveries/{stageId}/{itemId}/reset | 
*DeliveryApi* | [**search_deliveries**](docs/DeliveryApi.md#search_deliveries) | **POST** /api/v1/deliveries/search | 
*DeliveryApi* | [**skip_tracked_item**](docs/DeliveryApi.md#skip_tracked_item) | **PUT** /api/v1/deliveries/{stageId}/{itemId}/skip | 
*DeliveryApi* | [**update_delivery**](docs/DeliveryApi.md#update_delivery) | **PUT** /api/v1/deliveries/{deliveryId} | 
*DeliveryApi* | [**update_stage_in_delivery**](docs/DeliveryApi.md#update_stage_in_delivery) | **PUT** /api/v1/deliveries/{stageId} | 
*DeliveryApi* | [**update_tracked_item_in_delivery**](docs/DeliveryApi.md#update_tracked_item_in_delivery) | **PUT** /api/v1/deliveries/{itemId} | 
*DeliveryApi* | [**update_transition_in_delivery**](docs/DeliveryApi.md#update_transition_in_delivery) | **PUT** /api/v1/deliveries/{transitionId} | 
*DeliveryPatternApi* | [**check_title**](docs/DeliveryPatternApi.md#check_title) | **POST** /api/v1/delivery-patterns/checkTitle | 
*DeliveryPatternApi* | [**create_delivery_from_pattern**](docs/DeliveryPatternApi.md#create_delivery_from_pattern) | **POST** /api/v1/delivery-patterns/{patternId}/create | 
*DeliveryPatternApi* | [**create_pattern**](docs/DeliveryPatternApi.md#create_pattern) | **POST** /api/v1/delivery-patterns | 
*DeliveryPatternApi* | [**create_stage**](docs/DeliveryPatternApi.md#create_stage) | **POST** /api/v1/delivery-patterns/{patternId}/createStage | 
*DeliveryPatternApi* | [**create_stage1**](docs/DeliveryPatternApi.md#create_stage1) | **POST** /api/v1/delivery-patterns/{patternId}/stages | 
*DeliveryPatternApi* | [**create_stage2**](docs/DeliveryPatternApi.md#create_stage2) | **POST** /api/v1/delivery-patterns/{patternId}/stages/{position} | 
*DeliveryPatternApi* | [**create_tracked_item_in_pattern**](docs/DeliveryPatternApi.md#create_tracked_item_in_pattern) | **POST** /api/v1/delivery-patterns/{patternId}/tracked-items | 
*DeliveryPatternApi* | [**create_transition**](docs/DeliveryPatternApi.md#create_transition) | **POST** /api/v1/delivery-patterns/{stageId}/transitions | 
*DeliveryPatternApi* | [**delete_pattern**](docs/DeliveryPatternApi.md#delete_pattern) | **DELETE** /api/v1/delivery-patterns/{patternId} | 
*DeliveryPatternApi* | [**delete_stage**](docs/DeliveryPatternApi.md#delete_stage) | **DELETE** /api/v1/delivery-patterns/{stageId} | 
*DeliveryPatternApi* | [**delete_tracked_item_delivery_pattern**](docs/DeliveryPatternApi.md#delete_tracked_item_delivery_pattern) | **DELETE** /api/v1/delivery-patterns/{itemId} | 
*DeliveryPatternApi* | [**delete_transition**](docs/DeliveryPatternApi.md#delete_transition) | **DELETE** /api/v1/delivery-patterns/{transitionId} | 
*DeliveryPatternApi* | [**duplicate_pattern**](docs/DeliveryPatternApi.md#duplicate_pattern) | **POST** /api/v1/delivery-patterns/{patternId}/duplicate | 
*DeliveryPatternApi* | [**get_pattern**](docs/DeliveryPatternApi.md#get_pattern) | **GET** /api/v1/delivery-patterns/{patternId} | 
*DeliveryPatternApi* | [**get_pattern_by_id_or_title**](docs/DeliveryPatternApi.md#get_pattern_by_id_or_title) | **GET** /api/v1/delivery-patterns/{patternIdOrTitle} | 
*DeliveryPatternApi* | [**get_stages_in_pattern**](docs/DeliveryPatternApi.md#get_stages_in_pattern) | **GET** /api/v1/delivery-patterns/{patternId}/stages | 
*DeliveryPatternApi* | [**get_tracked_items_in_pattern**](docs/DeliveryPatternApi.md#get_tracked_items_in_pattern) | **GET** /api/v1/delivery-patterns/{patternId}/tracked-items | 
*DeliveryPatternApi* | [**search_patterns**](docs/DeliveryPatternApi.md#search_patterns) | **POST** /api/v1/delivery-patterns/search | 
*DeliveryPatternApi* | [**update_pattern**](docs/DeliveryPatternApi.md#update_pattern) | **PUT** /api/v1/delivery-patterns/{patternId} | 
*DeliveryPatternApi* | [**update_stage_from_batch**](docs/DeliveryPatternApi.md#update_stage_from_batch) | **PUT** /api/v1/delivery-patterns/{stageId}/batched | 
*DeliveryPatternApi* | [**update_stage_in_pattern**](docs/DeliveryPatternApi.md#update_stage_in_pattern) | **PUT** /api/v1/delivery-patterns/{stageId} | 
*DeliveryPatternApi* | [**update_tracked_item_in_pattern**](docs/DeliveryPatternApi.md#update_tracked_item_in_pattern) | **PUT** /api/v1/delivery-patterns/{itemId} | 
*DeliveryPatternApi* | [**update_transition_in_pattern**](docs/DeliveryPatternApi.md#update_transition_in_pattern) | **PUT** /api/v1/delivery-patterns/{transitionId} | 
*DslApi* | [**export_template_to_x_file**](docs/DslApi.md#export_template_to_x_file) | **GET** /api/v1/dsl/export/{templateId} | 
*DslApi* | [**preview_export_template_to_x_file**](docs/DslApi.md#preview_export_template_to_x_file) | **GET** /api/v1/dsl/preview/{templateId} | 
*EnvironmentApi* | [**create_environment**](docs/EnvironmentApi.md#create_environment) | **POST** /api/v1/environments | 
*EnvironmentApi* | [**delete_environment**](docs/EnvironmentApi.md#delete_environment) | **DELETE** /api/v1/environments/{environmentId} | 
*EnvironmentApi* | [**get_deployable_applications_for_environment**](docs/EnvironmentApi.md#get_deployable_applications_for_environment) | **GET** /api/v1/environments/{environmentId}/applications | 
*EnvironmentApi* | [**get_environment**](docs/EnvironmentApi.md#get_environment) | **GET** /api/v1/environments/{environmentId} | 
*EnvironmentApi* | [**get_reservations_for_environment**](docs/EnvironmentApi.md#get_reservations_for_environment) | **GET** /api/v1/environments/{environmentId}/reservations | 
*EnvironmentApi* | [**search_environments**](docs/EnvironmentApi.md#search_environments) | **POST** /api/v1/environments/search | 
*EnvironmentApi* | [**update_environment**](docs/EnvironmentApi.md#update_environment) | **PUT** /api/v1/environments/{environmentId} | 
*EnvironmentLabelApi* | [**create_label**](docs/EnvironmentLabelApi.md#create_label) | **POST** /api/v1/environments/labels | 
*EnvironmentLabelApi* | [**delete_environment_label**](docs/EnvironmentLabelApi.md#delete_environment_label) | **DELETE** /api/v1/environments/labels/{environmentLabelId} | 
*EnvironmentLabelApi* | [**get_label_by_id**](docs/EnvironmentLabelApi.md#get_label_by_id) | **GET** /api/v1/environments/labels/{environmentLabelId} | 
*EnvironmentLabelApi* | [**search_labels**](docs/EnvironmentLabelApi.md#search_labels) | **POST** /api/v1/environments/labels/search | 
*EnvironmentLabelApi* | [**update_label**](docs/EnvironmentLabelApi.md#update_label) | **PUT** /api/v1/environments/labels/{environmentLabelId} | 
*EnvironmentReservationApi* | [**add_application**](docs/EnvironmentReservationApi.md#add_application) | **POST** /api/v1/environments/reservations/{environmentReservationId} | 
*EnvironmentReservationApi* | [**create_reservation**](docs/EnvironmentReservationApi.md#create_reservation) | **POST** /api/v1/environments/reservations | 
*EnvironmentReservationApi* | [**delete_environment_reservation**](docs/EnvironmentReservationApi.md#delete_environment_reservation) | **DELETE** /api/v1/environments/reservations/{environmentReservationId} | 
*EnvironmentReservationApi* | [**get_reservation**](docs/EnvironmentReservationApi.md#get_reservation) | **GET** /api/v1/environments/reservations/{environmentReservationId} | 
*EnvironmentReservationApi* | [**search_reservations**](docs/EnvironmentReservationApi.md#search_reservations) | **POST** /api/v1/environments/reservations/search | 
*EnvironmentReservationApi* | [**update_reservation**](docs/EnvironmentReservationApi.md#update_reservation) | **PUT** /api/v1/environments/reservations/{environmentReservationId} | 
*EnvironmentStageApi* | [**create_stage3**](docs/EnvironmentStageApi.md#create_stage3) | **POST** /api/v1/environments/stages | 
*EnvironmentStageApi* | [**delete_environment_stage**](docs/EnvironmentStageApi.md#delete_environment_stage) | **DELETE** /api/v1/environments/stages/{environmentStageId} | 
*EnvironmentStageApi* | [**get_stage_by_id**](docs/EnvironmentStageApi.md#get_stage_by_id) | **GET** /api/v1/environments/stages/{environmentStageId} | 
*EnvironmentStageApi* | [**search_stages**](docs/EnvironmentStageApi.md#search_stages) | **POST** /api/v1/environments/stages/search | 
*EnvironmentStageApi* | [**update_stage_in_environment**](docs/EnvironmentStageApi.md#update_stage_in_environment) | **PUT** /api/v1/environments/stages/{environmentStageId} | 
*FacetApi* | [**create_facet**](docs/FacetApi.md#create_facet) | **POST** /api/v1/facets | 
*FacetApi* | [**delete_facet**](docs/FacetApi.md#delete_facet) | **DELETE** /api/v1/facets/{facetId} | 
*FacetApi* | [**get_facet**](docs/FacetApi.md#get_facet) | **GET** /api/v1/facets/{facetId} | 
*FacetApi* | [**get_facet_types**](docs/FacetApi.md#get_facet_types) | **GET** /api/v1/facets/types | 
*FacetApi* | [**search_facets**](docs/FacetApi.md#search_facets) | **POST** /api/v1/facets/search | 
*FacetApi* | [**update_facet**](docs/FacetApi.md#update_facet) | **PUT** /api/v1/facets/{facetId} | 
*FolderApi* | [**add_folder**](docs/FolderApi.md#add_folder) | **POST** /api/v1/folders/{folderId} | 
*FolderApi* | [**create_folder_variable**](docs/FolderApi.md#create_folder_variable) | **POST** /api/v1/folders/{folderId}/variables | 
*FolderApi* | [**delete_folder**](docs/FolderApi.md#delete_folder) | **DELETE** /api/v1/folders/{folderId} | 
*FolderApi* | [**delete_folder_variable**](docs/FolderApi.md#delete_folder_variable) | **DELETE** /api/v1/folders/{folderId}/{variableId} | 
*FolderApi* | [**find**](docs/FolderApi.md#find) | **GET** /api/v1/folders/find | 
*FolderApi* | [**get_folder**](docs/FolderApi.md#get_folder) | **GET** /api/v1/folders/{folderId} | 
*FolderApi* | [**get_folder_permissions**](docs/FolderApi.md#get_folder_permissions) | **GET** /api/v1/folders/permissions | 
*FolderApi* | [**get_folder_teams**](docs/FolderApi.md#get_folder_teams) | **GET** /api/v1/folders/{folderId}/teams | 
*FolderApi* | [**get_folder_templates**](docs/FolderApi.md#get_folder_templates) | **GET** /api/v1/folders/{folderId}/templates | 
*FolderApi* | [**get_folder_variable**](docs/FolderApi.md#get_folder_variable) | **GET** /api/v1/folders/{folderId}/{variableId} | 
*FolderApi* | [**is_folder_owner**](docs/FolderApi.md#is_folder_owner) | **GET** /api/v1/folders/{folderId}/folderOwner | 
*FolderApi* | [**list**](docs/FolderApi.md#list) | **GET** /api/v1/folders/{folderId}/list | 
*FolderApi* | [**list_root**](docs/FolderApi.md#list_root) | **GET** /api/v1/folders/list | 
*FolderApi* | [**list_variable_values**](docs/FolderApi.md#list_variable_values) | **GET** /api/v1/folders/{folderId}/variableValues | 
*FolderApi* | [**list_variables**](docs/FolderApi.md#list_variables) | **GET** /api/v1/folders/{folderId}/variables | 
*FolderApi* | [**move**](docs/FolderApi.md#move) | **POST** /api/v1/folders/{folderId}/move | 
*FolderApi* | [**move_template**](docs/FolderApi.md#move_template) | **POST** /api/v1/folders/{folderId}/templates/{templateId} | 
*FolderApi* | [**rename_folder**](docs/FolderApi.md#rename_folder) | **POST** /api/v1/folders/{folderId}/rename | 
*FolderApi* | [**search_releases_folder**](docs/FolderApi.md#search_releases_folder) | **POST** /api/v1/folders/{folderId}/releases | 
*FolderApi* | [**set_folder_teams**](docs/FolderApi.md#set_folder_teams) | **POST** /api/v1/folders/{folderId}/teams | 
*FolderApi* | [**update_folder_variable**](docs/FolderApi.md#update_folder_variable) | **PUT** /api/v1/folders/{folderId}/{variableId} | 
*PermissionsApi* | [**get_global_permissions**](docs/PermissionsApi.md#get_global_permissions) | **GET** /api/v1/global-permissions | 
*PhaseApi* | [**add_phase**](docs/PhaseApi.md#add_phase) | **POST** /api/v1/phases/{releaseId}/phase | 
*PhaseApi* | [**add_task_to_container**](docs/PhaseApi.md#add_task_to_container) | **POST** /api/v1/phases/{containerId}/tasks | 
*PhaseApi* | [**copy_phase**](docs/PhaseApi.md#copy_phase) | **POST** /api/v1/phases/{phaseId}/copy | 
*PhaseApi* | [**delete_phase**](docs/PhaseApi.md#delete_phase) | **DELETE** /api/v1/phases/{phaseId} | 
*PhaseApi* | [**get_phase**](docs/PhaseApi.md#get_phase) | **GET** /api/v1/phases/{phaseId} | 
*PhaseApi* | [**search_phases**](docs/PhaseApi.md#search_phases) | **GET** /api/v1/phases/search | 
*PhaseApi* | [**search_phases_by_title**](docs/PhaseApi.md#search_phases_by_title) | **GET** /api/v1/phases/byTitle | 
*PhaseApi* | [**update_phase**](docs/PhaseApi.md#update_phase) | **PUT** /api/v1/phases/{phaseId} | 
*PlannerApi* | [**get_active_releases**](docs/PlannerApi.md#get_active_releases) | **GET** /api/v1/analytics/planner/active | 
*PlannerApi* | [**get_completed_releases**](docs/PlannerApi.md#get_completed_releases) | **GET** /api/v1/analytics/planner/completed | 
*PlannerApi* | [**get_releases_by_ids**](docs/PlannerApi.md#get_releases_by_ids) | **POST** /api/v1/analytics/planner/byIds | 
*ReleaseApi* | [**abort**](docs/ReleaseApi.md#abort) | **POST** /api/v1/releases/{releaseId}/abort | 
*ReleaseApi* | [**count_releases**](docs/ReleaseApi.md#count_releases) | **POST** /api/v1/releases/count | 
*ReleaseApi* | [**create_release_variable**](docs/ReleaseApi.md#create_release_variable) | **POST** /api/v1/releases/{releaseId}/variables | 
*ReleaseApi* | [**delete_release**](docs/ReleaseApi.md#delete_release) | **DELETE** /api/v1/releases/{releaseId} | 
*ReleaseApi* | [**delete_release_variable**](docs/ReleaseApi.md#delete_release_variable) | **DELETE** /api/v1/releases/{variableId} | 
*ReleaseApi* | [**download_attachment**](docs/ReleaseApi.md#download_attachment) | **GET** /api/v1/releases/attachments/{attachmentId} | 
*ReleaseApi* | [**full_search_releases**](docs/ReleaseApi.md#full_search_releases) | **POST** /api/v1/releases/fullSearch | 
*ReleaseApi* | [**get_active_tasks**](docs/ReleaseApi.md#get_active_tasks) | **GET** /api/v1/releases/{releaseId}/active-tasks | 
*ReleaseApi* | [**get_archived_release**](docs/ReleaseApi.md#get_archived_release) | **GET** /api/v1/releases/archived/{releaseId} | 
*ReleaseApi* | [**get_possible_release_variable_values**](docs/ReleaseApi.md#get_possible_release_variable_values) | **GET** /api/v1/releases/{variableId}/possibleValues | 
*ReleaseApi* | [**get_release**](docs/ReleaseApi.md#get_release) | **GET** /api/v1/releases/{releaseId} | 
*ReleaseApi* | [**get_release_permissions**](docs/ReleaseApi.md#get_release_permissions) | **GET** /api/v1/releases/permissions | 
*ReleaseApi* | [**get_release_teams**](docs/ReleaseApi.md#get_release_teams) | **GET** /api/v1/releases/{releaseId}/teams | 
*ReleaseApi* | [**get_release_variable**](docs/ReleaseApi.md#get_release_variable) | **GET** /api/v1/releases/{variableId} | 
*ReleaseApi* | [**get_release_variables**](docs/ReleaseApi.md#get_release_variables) | **GET** /api/v1/releases/{releaseId}/variables | 
*ReleaseApi* | [**get_releases**](docs/ReleaseApi.md#get_releases) | **GET** /api/v1/releases | 
*ReleaseApi* | [**get_variable_values**](docs/ReleaseApi.md#get_variable_values) | **GET** /api/v1/releases/{releaseId}/variableValues | 
*ReleaseApi* | [**is_variable_used_release**](docs/ReleaseApi.md#is_variable_used_release) | **GET** /api/v1/releases/{variableId}/used | 
*ReleaseApi* | [**replace_release_variables**](docs/ReleaseApi.md#replace_release_variables) | **POST** /api/v1/releases/{variableId}/replace | 
*ReleaseApi* | [**restart_phases**](docs/ReleaseApi.md#restart_phases) | **POST** /api/v1/releases/{releaseId}/restart | 
*ReleaseApi* | [**resume**](docs/ReleaseApi.md#resume) | **POST** /api/v1/releases/{releaseId}/resume | 
*ReleaseApi* | [**search_releases_by_title**](docs/ReleaseApi.md#search_releases_by_title) | **GET** /api/v1/releases/byTitle | 
*ReleaseApi* | [**search_releases_release**](docs/ReleaseApi.md#search_releases_release) | **POST** /api/v1/releases/search | 
*ReleaseApi* | [**set_release_teams**](docs/ReleaseApi.md#set_release_teams) | **POST** /api/v1/releases/{releaseId}/teams | 
*ReleaseApi* | [**start_release**](docs/ReleaseApi.md#start_release) | **POST** /api/v1/releases/{releaseId}/start | 
*ReleaseApi* | [**update_release**](docs/ReleaseApi.md#update_release) | **PUT** /api/v1/releases/{releaseId} | 
*ReleaseApi* | [**update_release_variable**](docs/ReleaseApi.md#update_release_variable) | **PUT** /api/v1/releases/{variableId} | 
*ReleaseApi* | [**update_release_variables**](docs/ReleaseApi.md#update_release_variables) | **PUT** /api/v1/releases/{releaseId}/variables | 
*ReleaseGroupApi* | [**add_members_to_group**](docs/ReleaseGroupApi.md#add_members_to_group) | **POST** /api/v1/release-groups/{groupId}/members | 
*ReleaseGroupApi* | [**create_group**](docs/ReleaseGroupApi.md#create_group) | **POST** /api/v1/release-groups | 
*ReleaseGroupApi* | [**delete_group**](docs/ReleaseGroupApi.md#delete_group) | **DELETE** /api/v1/release-groups/{groupId} | 
*ReleaseGroupApi* | [**get_group**](docs/ReleaseGroupApi.md#get_group) | **GET** /api/v1/release-groups/{groupId} | 
*ReleaseGroupApi* | [**get_members**](docs/ReleaseGroupApi.md#get_members) | **GET** /api/v1/release-groups/{groupId}/members | 
*ReleaseGroupApi* | [**get_release_group_timeline**](docs/ReleaseGroupApi.md#get_release_group_timeline) | **GET** /api/v1/release-groups/{groupId}/timeline | 
*ReleaseGroupApi* | [**remove_members_from_group**](docs/ReleaseGroupApi.md#remove_members_from_group) | **DELETE** /api/v1/release-groups/{groupId}/members | 
*ReleaseGroupApi* | [**search_groups**](docs/ReleaseGroupApi.md#search_groups) | **POST** /api/v1/release-groups/search | 
*ReleaseGroupApi* | [**update_group**](docs/ReleaseGroupApi.md#update_group) | **PUT** /api/v1/release-groups/{groupId} | 
*ReportApi* | [**download_release_report**](docs/ReportApi.md#download_release_report) | **GET** /api/v1/reports/download/{reportType}/{releaseId} | 
*ReportApi* | [**get_records_for_release**](docs/ReportApi.md#get_records_for_release) | **GET** /api/v1/reports/records/{releaseId} | 
*ReportApi* | [**get_records_for_task**](docs/ReportApi.md#get_records_for_task) | **GET** /api/v1/reports/records/{taskId} | 
*ReportApi* | [**search_records**](docs/ReportApi.md#search_records) | **POST** /api/v1/reports/records/search | 
*RiskApi* | [**copy_risk_profile**](docs/RiskApi.md#copy_risk_profile) | **POST** /api/v1/risks/profiles/{riskProfileId}/copy | 
*RiskApi* | [**create_risk_profile**](docs/RiskApi.md#create_risk_profile) | **POST** /api/v1/risks/profiles | 
*RiskApi* | [**delete_risk_profile**](docs/RiskApi.md#delete_risk_profile) | **DELETE** /api/v1/risks/profiles/{riskProfileId} | 
*RiskApi* | [**get_all_risk_assessors**](docs/RiskApi.md#get_all_risk_assessors) | **GET** /api/v1/risks/assessors | 
*RiskApi* | [**get_risk**](docs/RiskApi.md#get_risk) | **GET** /api/v1/risks/{riskId} | 
*RiskApi* | [**get_risk_global_thresholds**](docs/RiskApi.md#get_risk_global_thresholds) | **GET** /api/v1/risks/config | 
*RiskApi* | [**get_risk_profile**](docs/RiskApi.md#get_risk_profile) | **GET** /api/v1/risks/profiles/{riskProfileId} | 
*RiskApi* | [**get_risk_profiles**](docs/RiskApi.md#get_risk_profiles) | **GET** /api/v1/risks/profiles | 
*RiskApi* | [**update_risk_global_thresholds**](docs/RiskApi.md#update_risk_global_thresholds) | **PUT** /api/v1/risks/config | 
*RiskApi* | [**update_risk_profile**](docs/RiskApi.md#update_risk_profile) | **PUT** /api/v1/risks/profiles/{riskProfileId} | 
*RiskAssessmentApi* | [**get_assessment**](docs/RiskAssessmentApi.md#get_assessment) | **GET** /api/v1/risks/assessments/{riskAssessmentId} | 
*RolesApi* | [**create_roles**](docs/RolesApi.md#create_roles) | **POST** /api/v1/roles | 
*RolesApi* | [**create_roles1**](docs/RolesApi.md#create_roles1) | **POST** /api/v1/roles/{roleName} | 
*RolesApi* | [**delete_roles**](docs/RolesApi.md#delete_roles) | **DELETE** /api/v1/roles/{roleName} | 
*RolesApi* | [**get_role**](docs/RolesApi.md#get_role) | **GET** /api/v1/roles/{roleName} | 
*RolesApi* | [**get_roles**](docs/RolesApi.md#get_roles) | **GET** /api/v1/roles | 
*RolesApi* | [**rename_roles**](docs/RolesApi.md#rename_roles) | **POST** /api/v1/roles/{roleName}/rename | 
*RolesApi* | [**update_roles**](docs/RolesApi.md#update_roles) | **PUT** /api/v1/roles | 
*RolesApi* | [**update_roles1**](docs/RolesApi.md#update_roles1) | **PUT** /api/v1/roles/{roleName} | 
*TaskApi* | [**abort_task**](docs/TaskApi.md#abort_task) | **POST** /api/v1/tasks/{taskId}/abort | 
*TaskApi* | [**add_attachments**](docs/TaskApi.md#add_attachments) | **POST** /api/v1/tasks/{taskId}/attachments | 
*TaskApi* | [**add_condition**](docs/TaskApi.md#add_condition) | **POST** /api/v1/tasks/{taskId}/conditions | 
*TaskApi* | [**add_dependency**](docs/TaskApi.md#add_dependency) | **POST** /api/v1/tasks/{taskId}/dependencies/{targetId} | 
*TaskApi* | [**add_task_task**](docs/TaskApi.md#add_task_task) | **POST** /api/v1/tasks/{containerId}/tasks | 
*TaskApi* | [**assign_task**](docs/TaskApi.md#assign_task) | **POST** /api/v1/tasks/{taskId}/assign/{username} | 
*TaskApi* | [**change_task_type**](docs/TaskApi.md#change_task_type) | **POST** /api/v1/tasks/{taskId}/changeType | 
*TaskApi* | [**comment_task**](docs/TaskApi.md#comment_task) | **POST** /api/v1/tasks/{taskId}/comment | 
*TaskApi* | [**complete_task**](docs/TaskApi.md#complete_task) | **POST** /api/v1/tasks/{taskId}/complete | 
*TaskApi* | [**copy_task**](docs/TaskApi.md#copy_task) | **POST** /api/v1/tasks/{taskId}/copy | 
*TaskApi* | [**delete_attachment**](docs/TaskApi.md#delete_attachment) | **DELETE** /api/v1/tasks/{taskId}/attachments/{attachmentId} | 
*TaskApi* | [**delete_condition**](docs/TaskApi.md#delete_condition) | **DELETE** /api/v1/tasks/{conditionId} | 
*TaskApi* | [**delete_dependency**](docs/TaskApi.md#delete_dependency) | **DELETE** /api/v1/tasks/{dependencyId} | 
*TaskApi* | [**delete_task**](docs/TaskApi.md#delete_task) | **DELETE** /api/v1/tasks/{taskId} | 
*TaskApi* | [**fail_task**](docs/TaskApi.md#fail_task) | **POST** /api/v1/tasks/{taskId}/fail | 
*TaskApi* | [**get_task**](docs/TaskApi.md#get_task) | **GET** /api/v1/tasks/{taskId} | 
*TaskApi* | [**get_task_variables**](docs/TaskApi.md#get_task_variables) | **GET** /api/v1/tasks/{taskId}/variables | 
*TaskApi* | [**lock_task**](docs/TaskApi.md#lock_task) | **PUT** /api/v1/tasks/{taskId}/lock | 
*TaskApi* | [**reopen_task**](docs/TaskApi.md#reopen_task) | **POST** /api/v1/tasks/{taskId}/reopen | 
*TaskApi* | [**retry_task**](docs/TaskApi.md#retry_task) | **POST** /api/v1/tasks/{taskId}/retry | 
*TaskApi* | [**search_tasks_by_title**](docs/TaskApi.md#search_tasks_by_title) | **GET** /api/v1/tasks/byTitle | 
*TaskApi* | [**skip_task**](docs/TaskApi.md#skip_task) | **POST** /api/v1/tasks/{taskId}/skip | 
*TaskApi* | [**start_task**](docs/TaskApi.md#start_task) | **POST** /api/v1/tasks/{taskId}/start | 
*TaskApi* | [**start_task1**](docs/TaskApi.md#start_task1) | **POST** /api/v1/tasks/{taskId}/startNow | 
*TaskApi* | [**unlock_task**](docs/TaskApi.md#unlock_task) | **DELETE** /api/v1/tasks/{taskId}/lock | 
*TaskApi* | [**update_condition**](docs/TaskApi.md#update_condition) | **POST** /api/v1/tasks/{conditionId} | 
*TaskApi* | [**update_input_variables**](docs/TaskApi.md#update_input_variables) | **PUT** /api/v1/tasks/{taskId}/variables | 
*TaskApi* | [**update_task**](docs/TaskApi.md#update_task) | **PUT** /api/v1/tasks/{taskId} | 
*TemplateApi* | [**copy_template**](docs/TemplateApi.md#copy_template) | **POST** /api/v1/templates/{templateId}/copy | 
*TemplateApi* | [**create_template**](docs/TemplateApi.md#create_template) | **POST** /api/v1/templates | 
*TemplateApi* | [**create_template1**](docs/TemplateApi.md#create_template1) | **POST** /api/v1/templates/{templateId}/create | 
*TemplateApi* | [**create_template_variable**](docs/TemplateApi.md#create_template_variable) | **POST** /api/v1/templates/{templateId}/variables | 
*TemplateApi* | [**delete_template**](docs/TemplateApi.md#delete_template) | **DELETE** /api/v1/templates/{templateId} | 
*TemplateApi* | [**delete_template_variable**](docs/TemplateApi.md#delete_template_variable) | **DELETE** /api/v1/templates/{variableId} | 
*TemplateApi* | [**export_template_to_zip**](docs/TemplateApi.md#export_template_to_zip) | **GET** /api/v1/templates/zip/{templateId} | 
*TemplateApi* | [**get_possible_template_variable_values**](docs/TemplateApi.md#get_possible_template_variable_values) | **GET** /api/v1/templates/{variableId}/possibleValues | 
*TemplateApi* | [**get_template**](docs/TemplateApi.md#get_template) | **GET** /api/v1/templates/{templateId} | 
*TemplateApi* | [**get_template_permissions**](docs/TemplateApi.md#get_template_permissions) | **GET** /api/v1/templates/permissions | 
*TemplateApi* | [**get_template_teams**](docs/TemplateApi.md#get_template_teams) | **GET** /api/v1/templates/{templateId}/teams | 
*TemplateApi* | [**get_template_variable**](docs/TemplateApi.md#get_template_variable) | **GET** /api/v1/templates/{variableId} | 
*TemplateApi* | [**get_template_variables**](docs/TemplateApi.md#get_template_variables) | **GET** /api/v1/templates/{templateId}/variables | 
*TemplateApi* | [**get_templates**](docs/TemplateApi.md#get_templates) | **GET** /api/v1/templates | 
*TemplateApi* | [**import_template**](docs/TemplateApi.md#import_template) | **POST** /api/v1/templates/import | 
*TemplateApi* | [**is_variable_used_template**](docs/TemplateApi.md#is_variable_used_template) | **GET** /api/v1/templates/{variableId}/used | 
*TemplateApi* | [**replace_template_variables**](docs/TemplateApi.md#replace_template_variables) | **POST** /api/v1/templates/{variableId}/replace | 
*TemplateApi* | [**set_template_teams**](docs/TemplateApi.md#set_template_teams) | **POST** /api/v1/templates/{templateId}/teams | 
*TemplateApi* | [**start_template**](docs/TemplateApi.md#start_template) | **POST** /api/v1/templates/{templateId}/start | 
*TemplateApi* | [**update_template**](docs/TemplateApi.md#update_template) | **PUT** /api/v1/templates/{templateId} | 
*TemplateApi* | [**update_template_variable**](docs/TemplateApi.md#update_template_variable) | **PUT** /api/v1/templates/{variableId} | 
*TemplateApi* | [**update_template_variables**](docs/TemplateApi.md#update_template_variables) | **PUT** /api/v1/templates/{releaseId}/variables | 
*TriggersApi* | [**add_trigger**](docs/TriggersApi.md#add_trigger) | **POST** /api/v1/triggers | 
*TriggersApi* | [**disable_all_triggers**](docs/TriggersApi.md#disable_all_triggers) | **POST** /api/v1/triggers/disable/all | 
*TriggersApi* | [**disable_trigger**](docs/TriggersApi.md#disable_trigger) | **PUT** /api/v1/triggers/{triggerId}/disable | 
*TriggersApi* | [**disable_triggers**](docs/TriggersApi.md#disable_triggers) | **POST** /api/v1/triggers/disable | 
*TriggersApi* | [**enable_all_triggers**](docs/TriggersApi.md#enable_all_triggers) | **POST** /api/v1/triggers/enable/all | 
*TriggersApi* | [**enable_trigger**](docs/TriggersApi.md#enable_trigger) | **PUT** /api/v1/triggers/{triggerId}/enable | 
*TriggersApi* | [**enable_triggers**](docs/TriggersApi.md#enable_triggers) | **POST** /api/v1/triggers/enable | 
*TriggersApi* | [**get_trigger**](docs/TriggersApi.md#get_trigger) | **GET** /api/v1/triggers/{triggerId} | 
*TriggersApi* | [**get_types**](docs/TriggersApi.md#get_types) | **GET** /api/v1/triggers/types | 
*TriggersApi* | [**remove_trigger**](docs/TriggersApi.md#remove_trigger) | **DELETE** /api/v1/triggers/{triggerId} | 
*TriggersApi* | [**run_trigger**](docs/TriggersApi.md#run_trigger) | **POST** /api/v1/triggers/{triggerId}/run | 
*TriggersApi* | [**search_triggers**](docs/TriggersApi.md#search_triggers) | **GET** /api/v1/triggers | 
*TriggersApi* | [**update_trigger**](docs/TriggersApi.md#update_trigger) | **PUT** /api/v1/triggers/{triggerId} | 
*UserApi* | [**create_user**](docs/UserApi.md#create_user) | **POST** /api/v1/users/{username} | 
*UserApi* | [**delete_user_rest**](docs/UserApi.md#delete_user_rest) | **DELETE** /api/v1/users/{username} | 
*UserApi* | [**find_users**](docs/UserApi.md#find_users) | **GET** /api/v1/users | 
*UserApi* | [**get_user**](docs/UserApi.md#get_user) | **GET** /api/v1/users/{username} | 
*UserApi* | [**update_password**](docs/UserApi.md#update_password) | **POST** /api/v1/users/{username}/password | 
*UserApi* | [**update_user**](docs/UserApi.md#update_user) | **PUT** /api/v1/users/{username} | 
*UserApi* | [**update_users_rest**](docs/UserApi.md#update_users_rest) | **PUT** /api/v1/users | 


## Documentation For Models

 - [AbortRelease](docs/AbortRelease.md)
 - [ActivityLogEntry](docs/ActivityLogEntry.md)
 - [ApplicationFilters](docs/ApplicationFilters.md)
 - [ApplicationForm](docs/ApplicationForm.md)
 - [ApplicationView](docs/ApplicationView.md)
 - [Attachment](docs/Attachment.md)
 - [BaseApplicationView](docs/BaseApplicationView.md)
 - [BaseEnvironmentView](docs/BaseEnvironmentView.md)
 - [BlackoutMetadata](docs/BlackoutMetadata.md)
 - [BlackoutPeriod](docs/BlackoutPeriod.md)
 - [BulkActionResultView](docs/BulkActionResultView.md)
 - [ChangePasswordView](docs/ChangePasswordView.md)
 - [CiProperty](docs/CiProperty.md)
 - [Comment](docs/Comment.md)
 - [Comment1](docs/Comment1.md)
 - [CompleteTransition](docs/CompleteTransition.md)
 - [Condition](docs/Condition.md)
 - [Condition1](docs/Condition1.md)
 - [ConfigurationFacet](docs/ConfigurationFacet.md)
 - [ConfigurationView](docs/ConfigurationView.md)
 - [CopyTemplate](docs/CopyTemplate.md)
 - [CreateDelivery](docs/CreateDelivery.md)
 - [CreateDeliveryStage](docs/CreateDeliveryStage.md)
 - [CreateRelease](docs/CreateRelease.md)
 - [Delivery](docs/Delivery.md)
 - [DeliveryFilters](docs/DeliveryFilters.md)
 - [DeliveryFlowReleaseInfo](docs/DeliveryFlowReleaseInfo.md)
 - [DeliveryOrderMode](docs/DeliveryOrderMode.md)
 - [DeliveryPatternFilters](docs/DeliveryPatternFilters.md)
 - [DeliveryStatus](docs/DeliveryStatus.md)
 - [DeliveryTimeline](docs/DeliveryTimeline.md)
 - [Dependency](docs/Dependency.md)
 - [DuplicateDeliveryPattern](docs/DuplicateDeliveryPattern.md)
 - [EnvironmentFilters](docs/EnvironmentFilters.md)
 - [EnvironmentForm](docs/EnvironmentForm.md)
 - [EnvironmentLabelFilters](docs/EnvironmentLabelFilters.md)
 - [EnvironmentLabelForm](docs/EnvironmentLabelForm.md)
 - [EnvironmentLabelView](docs/EnvironmentLabelView.md)
 - [EnvironmentReservationForm](docs/EnvironmentReservationForm.md)
 - [EnvironmentReservationSearchView](docs/EnvironmentReservationSearchView.md)
 - [EnvironmentReservationView](docs/EnvironmentReservationView.md)
 - [EnvironmentStageFilters](docs/EnvironmentStageFilters.md)
 - [EnvironmentStageForm](docs/EnvironmentStageForm.md)
 - [EnvironmentStageView](docs/EnvironmentStageView.md)
 - [EnvironmentView](docs/EnvironmentView.md)
 - [ExternalVariableValue](docs/ExternalVariableValue.md)
 - [Facet](docs/Facet.md)
 - [FacetFilters](docs/FacetFilters.md)
 - [FacetScope](docs/FacetScope.md)
 - [FlagStatus](docs/FlagStatus.md)
 - [Folder](docs/Folder.md)
 - [FolderVariables](docs/FolderVariables.md)
 - [GateCondition](docs/GateCondition.md)
 - [GateTask](docs/GateTask.md)
 - [GlobalVariables](docs/GlobalVariables.md)
 - [ImportResult](docs/ImportResult.md)
 - [MemberType](docs/MemberType.md)
 - [ModelProperty](docs/ModelProperty.md)
 - [Phase](docs/Phase.md)
 - [PhaseStatus](docs/PhaseStatus.md)
 - [PhaseTimeline](docs/PhaseTimeline.md)
 - [PhaseVersion](docs/PhaseVersion.md)
 - [PlanItem](docs/PlanItem.md)
 - [PollType](docs/PollType.md)
 - [PrincipalView](docs/PrincipalView.md)
 - [ProjectedPhase](docs/ProjectedPhase.md)
 - [ProjectedRelease](docs/ProjectedRelease.md)
 - [ProjectedTask](docs/ProjectedTask.md)
 - [Release](docs/Release.md)
 - [ReleaseConfiguration](docs/ReleaseConfiguration.md)
 - [ReleaseCountResult](docs/ReleaseCountResult.md)
 - [ReleaseCountResults](docs/ReleaseCountResults.md)
 - [ReleaseExtension](docs/ReleaseExtension.md)
 - [ReleaseFullSearchResult](docs/ReleaseFullSearchResult.md)
 - [ReleaseGroup](docs/ReleaseGroup.md)
 - [ReleaseGroupFilters](docs/ReleaseGroupFilters.md)
 - [ReleaseGroupOrderMode](docs/ReleaseGroupOrderMode.md)
 - [ReleaseGroupStatus](docs/ReleaseGroupStatus.md)
 - [ReleaseGroupTimeline](docs/ReleaseGroupTimeline.md)
 - [ReleaseOrderDirection](docs/ReleaseOrderDirection.md)
 - [ReleaseOrderMode](docs/ReleaseOrderMode.md)
 - [ReleaseSearchResult](docs/ReleaseSearchResult.md)
 - [ReleaseStatus](docs/ReleaseStatus.md)
 - [ReleaseTimeline](docs/ReleaseTimeline.md)
 - [ReleaseTrigger](docs/ReleaseTrigger.md)
 - [ReleasesFilters](docs/ReleasesFilters.md)
 - [ReservationFilters](docs/ReservationFilters.md)
 - [ReservationSearchView](docs/ReservationSearchView.md)
 - [Risk](docs/Risk.md)
 - [RiskAssessment](docs/RiskAssessment.md)
 - [RiskAssessor](docs/RiskAssessor.md)
 - [RiskGlobalThresholds](docs/RiskGlobalThresholds.md)
 - [RiskProfile](docs/RiskProfile.md)
 - [RiskStatus](docs/RiskStatus.md)
 - [RiskStatusWithThresholds](docs/RiskStatusWithThresholds.md)
 - [RoleView](docs/RoleView.md)
 - [SharedConfigurationStatusResponse](docs/SharedConfigurationStatusResponse.md)
 - [Stage](docs/Stage.md)
 - [StageStatus](docs/StageStatus.md)
 - [StageTrackedItem](docs/StageTrackedItem.md)
 - [StartRelease](docs/StartRelease.md)
 - [StartTask](docs/StartTask.md)
 - [Subscriber](docs/Subscriber.md)
 - [SystemMessageSettings](docs/SystemMessageSettings.md)
 - [Task](docs/Task.md)
 - [TaskContainer](docs/TaskContainer.md)
 - [TaskRecoverOp](docs/TaskRecoverOp.md)
 - [TaskReportingRecord](docs/TaskReportingRecord.md)
 - [TaskStatus](docs/TaskStatus.md)
 - [Team](docs/Team.md)
 - [TeamMemberView](docs/TeamMemberView.md)
 - [TeamView](docs/TeamView.md)
 - [TimeFrame](docs/TimeFrame.md)
 - [TrackedItem](docs/TrackedItem.md)
 - [TrackedItemStatus](docs/TrackedItemStatus.md)
 - [Transition](docs/Transition.md)
 - [Trigger](docs/Trigger.md)
 - [TriggerExecutionStatus](docs/TriggerExecutionStatus.md)
 - [UsagePoint](docs/UsagePoint.md)
 - [UserAccount](docs/UserAccount.md)
 - [UserInputTask](docs/UserInputTask.md)
 - [ValidatePattern](docs/ValidatePattern.md)
 - [ValueProviderConfiguration](docs/ValueProviderConfiguration.md)
 - [ValueWithInterpolation](docs/ValueWithInterpolation.md)
 - [Variable](docs/Variable.md)
 - [Variable1](docs/Variable1.md)
 - [VariableOrValue](docs/VariableOrValue.md)


## Documentation For Authorization


## basicAuth

- **Type**: HTTP basic authentication


## patAuth

- **Type**: API key
- **API key parameter name**: x-release-personal-token
- **Location**: HTTP header


## Author




## Notes for Large OpenAPI documents
If the OpenAPI document is large, imports in digitalai.release.v1.apis and digitalai.release.v1.models may fail with a
RecursionError indicating the maximum recursion limit has been exceeded. In that case, there are a couple of solutions:

Solution 1:
Use specific imports for apis and models like:
- `from digitalai.release.v1.api.default_api import DefaultApi`
- `from digitalai.release.v1.model.pet import Pet`

Solution 2:
Before importing the package, adjust the maximum recursion limit as shown below:
```
import sys
sys.setrecursionlimit(1500)
import digitalai.release.v1
from digitalai.release.v1.apis import *
from digitalai.release.v1.models import *
```

